clear screen 
set echo on
@connect /
drop table t1;
drop table t2;

clear screen
create table t1
as
select * from stage 
 order by dbms_random.random;
alter table t1 add constraint t1_pk primary key(object_id);
alter table t1 add constraint check_gt_zero check (object_id>0);
create trigger t1_trigger 
before insert on t1
begin
	dbms_output.put_line( 'hello world' );
end;
/
pause

clear screen
select 'indexes', index_name from user_indexes where table_name = 'T1'
union all
select 'constraints', constraint_name from user_constraints where table_name = 'T1'
union all
select 'triggers', trigger_name from user_triggers where table_name = 'T1';
pause

clear screen
create table t2 (
OWNER                  VARCHAR2(30),
OBJECT_NAME            VARCHAR2(30),
SUBOBJECT_NAME         VARCHAR2(30),
OBJECT_ID              NUMBER,
DATA_OBJECT_ID         NUMBER,
OBJECT_TYPE            VARCHAR2(19),
CREATED                DATE,
LAST_DDL_TIME          DATE,
TIMESTAMP              VARCHAR2(19),
STATUS                 VARCHAR2(7),
TEMPORARY              VARCHAR2(1),
GENERATED              VARCHAR2(1),
SECONDARY              VARCHAR2(1),
NAMESPACE              NUMBER,
EDITION_NAME           VARCHAR2(30)
) partition by hash(object_id) partitions 8;
exec dbms_redefinition.can_redef_table( user, 'T1' );
pause

clear screen
exec dbms_monitor.session_trace_enable;
exec dbms_redefinition.start_redef_table( user, 'T1', 'T2', orderby_cols => 'OBJECT_ID' )
pause
@tk "sys=no"
select object_id, object_name from t1 OLD_TABLE where rownum<=5;
select object_id, object_name from t2 NEW_TABLE where rownum<=5;
pause

clear screen
variable nerrors number
begin
	dbms_redefinition.copy_table_dependents
	( user, 'T1', 'T2', 
	  copy_indexes => dbms_redefinition.cons_orig_params,
	  num_errors => :nerrors );
end;
/
print nerrors
pause

clear screen
select table_name, 'indexes', index_name from user_indexes where table_name in ('T1','T2')
union all
select table_name, 'constraints', constraint_name from user_constraints where table_name in ('T1','T2')
union all
select table_name, 'triggers', trigger_name from user_triggers where table_name in ('T1','T2');
pause

clear screen
exec dbms_redefinition.finish_redef_table( user, 'T1', 'T2' );
select object_id, object_name from t1 NEW_TABLE where rownum<=5;
select object_id, object_name from t2 OLD_TABLE where rownum<=5;
pause

clear screen
drop table t2;
select 'indexes', index_name from user_indexes where table_name = 'T1'
union all
select 'constraints', constraint_name from user_constraints where table_name = 'T1'
union all
select 'triggers', trigger_name from user_triggers where table_name = 'T1';
pause

clear screen
select dbms_metadata.get_ddl( 'TABLE', 'T1' ) from dual;
pause

clear screen
